# <u>IndexedChoiceSelector</u>
### <i>Basic selector class that displays given options with numbers.</i>


IndexedChoiceSelector is a basic selector class that displays given options with numbers. This allows the user to choose an option either by number, or by name.

<b>Import</b>

import IndexedChoiceSelector using ``